@@ -18,12 +18,12 @@ try:
     f=open(configfilename,'rt');
     lines=f.readlines();
     for l in lines:
-        if l.startswith('Default inputdirs:'):
-            default_inputdirs=l.strip().split(':')[1].strip()
-        elif l.startswith('Default outputdir:'):
-            default_outputdir=l.strip().split(':')[1].strip()
-        elif l.startswith('Default mask:'):
-            default_mask=l.strip().split(':')[1].strip()
+        if l.startswith('Default inputdirs='):
+            default_inputdirs=l.strip().split('=')[1].strip()
+        elif l.startswith('Default outputdir='):
+            default_outputdir=l.strip().split('=')[1].strip()
+        elif l.startswith('Default mask='):
+            default_mask=l.strip().split('=')[1].strip()
     f.close()
 except:
     pass
@@ -375,9 +375,9 @@ class MainWindow:
         pylab.close('all')
         try:
             f=open(configfilename,'wt');
-            f.write('Default inputdirs: %s\n'%self.inputdirs.get())
-            f.write('Default outputdir: %s\n'%self.outputdir.get())
-            f.write('Default mask: %s\n'%self.maskfilename.get())
+            f.write('Default inputdirs= %s\n'%self.inputdirs.get())
+            f.write('Default outputdir= %s\n'%self.outputdir.get())
+            f.write('Default mask= %s\n'%self.maskfilename.get())
             f.close()
         except IOError:
             pass
